<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="323"/>
        <source>Crash Report</source>
        <translation>Zgłaszanie błędów</translation>
    </message>
    <message>
        <location filename="../src/lxqtmodman.cpp" line="324"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; przestawało działać wiele razy. Przestanie być uruchamiane ponownie do następnego logowania.</translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Configuration file path.</source>
        <translation>Ścieżka pliku konfiguracyjnego.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <location filename="../src/main.cpp" line="63"/>
        <source>file</source>
        <translation>plik</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="63"/>
        <source>Window manager to use.</source>
        <translation>Używany menedżer okien.</translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="83"/>
        <source>DBus Environment</source>
        <translation>Środowisko DBus</translation>
    </message>
    <message>
        <location filename="../src/sessionapplication.cpp" line="84"/>
        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
        <translation>Środowisko aktywacji DBus nie zostało zaktualizowane. Niektóre aplikacje mogą nie działać poprawnie</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>Witamy w LXQt-Qt</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="65"/>
        <source>Other ...</source>
        <translation>Inne ...</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.cpp" line="66"/>
        <source>Choose your favorite one.</source>
        <translation>Wybierz swój ulubiony.</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Witamy w LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Wybierz swój domyślny menedżer okien.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>Możesz zmienić tą opcję w każdej chwili w ustawieniach sesji.</translation>
    </message>
</context>
</TS>
